#! /usr/bin/env python2
# encoding:utf-8
# python 2.7 测试通过
# python 3 更换适当的开发库就能使用，在此我们不额外提供

import sys
if sys.version_info.major == 3:
    import http.client as httplib  # , urllib.parse as urllib
elif sys.version_info.major == 2:
    import httplib
import json
import hashlib
import random
import time
from  .tools import SmsSenderUtil

class SmsSender:
    """ 发送类定义"""
    appid = 0
    appkey = ""
    url = "https://msg.yundashi.com/api/sms/send"

    def __init__(self, appid, appkey):
        self.appid = appid
        self.appkey = appkey
        self.util = SmsSenderUtil()

    def send(self, nation_code, phone_numbers, msg, extend, ext):
        """ 行业群发接口
        明确指定内容，如果有多个签名，请在内容中以【】的方式添加到信息内容中，否则系统将使用默认签名

        Args:
            nation_code: 国家码，如 86 为中国
            phone_number: 不带国家码的手机号
            msg: 信息内容，必须与申请的模板格式一致，否则将返回错误
            extend: 扩展码，可填空串
            ext: 服务端原样返回的参数，可填空串

        Returns:
            json string { "result": xxxx, "errmsg": "xxxxx" ... }，被省略的内容参见协议文档
            请求包体
            {
                "tel": {
                    "nationcode": "86",
                    "mobile": "13788888888"
                },
                "msg": "你的验证码是1234",
                "sig": "fdba654e05bc0d15796713a1a1a2318c",
                "time": 1479888540,
                "extend": "",
                "ext": ""
            }
            应答包体
            {
                "result": 0,
                "errmsg": "OK",
                "ext": "",
                "sid": "xxxxxxx",
                "fee": 1
            }
        """
        rnd = self.util.get_random()
        cur_time = self.util.get_cur_time()

        data = {}

        data["tel"] = self.util.phone_numbers_to_list(nation_code, phone_numbers)
        data["msg"] = msg
        data["sig"] = self.util.calculate_sig(self.appkey, rnd, cur_time, phone_numbers)
        data["time"] = cur_time
        data["extend"] = extend
        data["ext"] = ext

        whole_url = self.url + "?sdkappid=" + str(self.appid) + "&random=" + str(rnd)
        return self.util.send_post_request("msg.yundashi.com", whole_url, data)


class SmsMarketingSender:
    """ 群发类定义"""
    appid = 0
    appkey = ""
    url = "https://msg.yundashi.com/api/sms/marketing"

    def __init__(self, appid, appkey):
        self.appid = appid
        self.appkey = appkey
        self.util = SmsSenderUtil()

    def send(self, nation_code, phone_numbers, msg, extend, ext):
        """ 营销群发
        【注意】海外短信没有群发功能

        Args:
            nation_code: 国家码，如 86 为中国
            phone_numbers: 不带国家码的手机号列表
            msg: 信息内容，必须与申请的模板格式一致，否则将返回错误
            extend: 扩展码，可填空串
            ext: 服务端原样返回的参数，可填空串

        Returns:
            json string { "result": xxxx, "errmsg": "xxxxx" ... }，被省略的内容参见协议文档

        请求包体
        {
            "tel": [
                {
                    "nationcode": "86",
                    "mobile": "13788888888"
                },
                {
                    "nationcode": "86",
                    "mobile": "13788888889"
                }
            ],
            "msg": "你的验证码是1234",
            "sig": "fdba654e05bc0d15796713a1a1a2318c",
            "time": 1479888540,
            "extend": "",
            "ext": ""
        }
        应答包体
        {
            "result": 0,
            "errmsg": "OK",
            "ext": "",
            "detail": [
                {
                    "result": 0,
                    "errmsg": "OK",
                    "mobile": "13788888888",
                    "nationcode": "86",
                    "sid": "xxxxxxx",
                    "fee": 1
                },
                {
                    "result": 0,
                    "errmsg": "OK",
                    "mobile": "13788888889",
                    "nationcode": "86",
                    "sid": "xxxxxxx",
                    "fee": 1
                }
            ]
        }
        """
        rnd = self.util.get_random()
        cur_time = self.util.get_cur_time()

        data = {}

        data["tel"] = self.util.phone_numbers_to_list(nation_code, phone_numbers)
        data["msg"] = msg
        data["sig"] = self.util.calculate_sig(self.appkey, rnd, cur_time, phone_numbers)
        data["time"] = cur_time
        data["extend"] = extend
        data["ext"] = ext

        whole_url = self.url + "?sdkappid=" + str(self.appid) + "&random=" + str(rnd)
        return self.util.send_post_request("msg.yundashi.com", whole_url, data)
